import 'dart:convert';

class TopArtistsDataValue {
  final String artistName;
  final int count;

  const TopArtistsDataValue({required this.artistName, required this.count});

  factory TopArtistsDataValue.fromJson(Map<String, dynamic> json) {
    return TopArtistsDataValue(
      artistName: json['artistName'] as String,
      count: json['count'] as int,
    );
  }
}

class TopArtistsData {
  final List<TopArtistsDataValue> topArtists;

  const TopArtistsData({
    required this.topArtists,
  });

  factory TopArtistsData.fromJson(Map<String, dynamic> json) {
    List<TopArtistsDataValue> topArtists = [];

    json['top-artists'].forEach((element) {
      TopArtistsDataValue value = TopArtistsDataValue(
        artistName: element['artistName'] as String,
        count: element['count'] as int,
      );

      topArtists.add(value);
    });

    return TopArtistsData(
      topArtists: topArtists,
    );
  }

  factory TopArtistsData.createEmpty() {
    return TopArtistsData.fromJson({
      'top-artists': [],
    });
  }

  String toString() {
    List<Map<String, Object>> listArtists = [];

    this.topArtists.forEach((TopArtistsDataValue? item) {
      listArtists.add({
        'artistName': item != null ? item.artistName : '',
        'count': item != null ? item.count : 0,
      });
    });

    return jsonEncode({
      'top-artists': listArtists,
    });
  }
}
